summaryrefslogtreecommitdiff
path: root/build-openwrt.sh
diff options
context:
space:
mode:
Diffstat (limited to 'build-openwrt.sh')
-rwxr-xr-xbuild-openwrt.sh76
1 files changed, 13 insertions, 63 deletions
diff --git a/build-openwrt.sh b/build-openwrt.sh
index ceb61cf..ac2aad4 100755
--- a/build-openwrt.sh
+++ b/build-openwrt.sh
@@ -1,31 +1,33 @@
#!/bin/bash
#
# Work derived from ./quick_740n_ttn_bb.sh (Laurent Guerby <laurent@guery.net>)
+# Renamed from "CHD OpenWRT" to "CHD LEDE" on 2017-06-21
#
-# Copyright 2016 Ludovic Pouzenc <ludovic@pouzenc.fr>
+# Copyright 2017 Ludovic Pouzenc <ludovic@pouzenc.fr>
+# Copyright 2017 Nicolas Goaziou <mail@nicolasgoaziou.fr>
#
# CHD OpenWRT is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CHD OpenWRT is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with CHD OpenWRT. If not, see <http://www.gnu.org/licenses/>.
+# along with CHD LEDE. If not, see <http://www.gnu.org/licenses/>.
#
echo -n "$0 - " ; date
# Directories and source file URL
BUILD_DIR=${BUILD_DIR:-./build}
CACHE_DIR=${CACHE_DIR:-.}
-ORIG_TARBALL=OpenWrt-ImageBuilder-9a1fd3e-ar71xx-generic.Linux-x86_64.tar.bz2
-ORIG_URL=http://stg2.chd.sx/openwrt/chaos_calmer/15.05.1/ar71xx/generic/$ORIG_TARBALL
-PACKAGES="luci luci-mod-admin-full ip" # Base packages
-PACKAGES="$PACKAGES luci-i18n-base-en luci-i18n-firewall-en luci-i18n-base-fr luci-i18n-firewall-fr" # internationnalisation
+ORIG_TARBALL=lede-imagebuilder-17.01.2-ar71xx-generic.Linux-x86_64.tar.xz
+ORIG_URL=https://downloads.lede-project.org/releases/17.01.2/targets/ar71xx/generic/$ORIG_TARBALL
+PACKAGES="luci luci-mod-admin-full ip kmod-leds-gpio" # Base packages
+PACKAGES="$PACKAGES luci-i18n-base-en luci-i18n-firewall-en luci-i18n-base-fr luci-i18n-firewall-fr" # internationalisation
PACKAGES="$PACKAGES -kmod-ppp -kmod-pppoe -kmod-pppox" # Unusefull kernel modules
PACKAGES="$PACKAGES -luci-proto-ppp -ppp -ppp-mod-pppoe -odhcp6c" # Unusefull packages
@@ -38,13 +40,6 @@ fi
dnslist="185.131.40.1 fe80::31"
profile=$1
-case "$profile" in
- TLWR740|TLWR841)
- ;;
- *) echo "Unsupported profile '$profile', should be TLWR740 or TLWR841"
- exit 2
- ;;
-esac
ip4pub=$2
case "$ip4pub" in
@@ -99,20 +94,6 @@ if [ ! -f "$BUILD_DIR/Makefile" ]; then
wget -O "$CACHE_DIR/$ORIG_TARBALL" "$ORIG_URL"
fi
tar -x -C "$BUILD_DIR/" --strip-components=1 -f "$CACHE_DIR/$ORIG_TARBALL"
- # Hotfix about "logd" package not availble on chaos-calmer
- patch -d "$BUILD_DIR/" -p1 <<"EOT"
---- a/include/target.mk 2017-04-01 22:00:23.000000000 +0200
-+++ b/include/target.mk 2017-04-03 20:01:23.620028730 +0200
-@@ -12,7 +12,7 @@
- DEVICE_TYPE?=router
-
- # Default packages - the really basic set
--DEFAULT_PACKAGES:=base-files libc libgcc busybox dropbear mtd uci opkg netifd fstools logd
-+DEFAULT_PACKAGES:=base-files libc libgcc busybox dropbear mtd uci opkg netifd fstools
- # For nas targets
- DEFAULT_PACKAGES.nas:=block-mount fdisk lsblk mdadm
- # For router targets
-EOT
fi
cd "$BUILD_DIR/" || exit 5
@@ -124,22 +105,7 @@ mkdir -p extra_files/etc/config extra_files/etc/dropbear extra_files/etc/hotplug
###############################
# Use local replication of repositories
-cat > repositories.conf <<"EOT"
-## Place your custom repositories here, they must match the architecture and version.
-# src/gz chaos_calmer http://downloads.openwrt.org/chaos_calmer/15.05.1/ar71xx/generic/packages
-# src custom file:///usr/src/openwrt/bin/ar71xx/packages
-
-## Remote package repositories
-src/gz chaos_calmer_base http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/base
-src/gz chaos_calmer_luci http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/luci
-#src/gz chaos_calmer_packages http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/packages
-src/gz chaos_calmer_routing http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/routing
-#src/gz chaos_calmer_telephony http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/telephony
-#src/gz chaos_calmer_management http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/management
-
-## This is the local package repository, do not remove!
-src imagebuilder file:packages
-EOT
+sed --in-place -e 's#downloads.lede-project.org#localhost/lede-project#' repositories.conf
cat > extra_files/etc/dropbear/authorized_keys <<EOF
ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQCuRKy/uRhwFvR3JrCp2NKY0HUPl0m7INUjY9wemmEGA6pSH/9zb+MLX9ZfuDVo6gkMI2YZzdpwAZ7KE2tajDXHHl+KiycY3lcQizgQt3usxf7Eqz3pTWtZBOjrHs3hRloPugg8KXA8Sxko03f68v8lfUw+Kj4LHmnnozJc8Hxde3GjkFbyL9c9Z5rSYG82H217RWaSDnjYso9wyBZYkjTe6vu88fWls3+ZL8p8NdrgqMFO7C+zV38Mgk/G3PkC9SYdobgy58Cm/06jehWonuafZ6bXTH1J3qjogbcGfewNx4H4E7Lf1nl6UTdbAC24tZu3c/UXZQzND+yRRK1r0zen lpouzenc@ttn
@@ -390,35 +356,19 @@ cat > extra_files/etc/hotplug.d/button/01onoff <<"EOF"
}
EOF
-cat > extra_files/etc/banner <<"EOF"
- _______ ________ __
- | |.-----.-----.-----.| | | |.----.| |_
- | - || _ | -__| || | | || _|| _|
- |_______|| __|_____|__|__||________||__| |____|
- |__| W I R E L E S S F R E E D O M
- -----------------------------------------------------
- CHAOS CALMER (15.05.1, 9a1fd3e 2017-03-09)
- -----------------------------------------------------
- * 1 1/2 oz Gin Shake with a glassful
- * 1/4 oz Triple Sec of broken ice and pour
- * 3/4 oz Lime Juice unstrained into a goblet.
- * 1 1/2 oz Orange Juice
- * 1 tsp. Grenadine Syrup
- -----------------------------------------------------
-EOF
#######################
# Build Openwrt image #
#######################
make clean
-make image PROFILE=$profile PACKAGES="$PACKAGES" FILES="extra_files/"
+make image PROFILE=$profile PACKAGES="$PACKAGES" FILES="extra_files/" V=99
res=$?
echo
if [ $res -eq 0 ]
then echo "Image ready: "
- ls -la bin/ar71xx/openwrt*ar71xx-generic-tl-*-v*-squashfs-*
+ ls -la bin/targets/ar71xx/generic/*ar71xx-generic-tl-*-v*-squashfs-*
echo
else echo "Something went wrong, sorry"
fi
@@ -1,31 +1,33 @@
#
-# CHD OpenWRT is free software: you can redistribute it and/or modify
+# CHD LEDE is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
@@ -1,31 +1,33 @@
# (at your option) any later version.
#
-# CHD OpenWRT is distributed in the hope that it will be useful,
+# CHD LEDE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the